Added test for ballot and removing HIP_FUNCTION from hipSampleAtomicsTest.cpp -sandeep

This commit is contained in:
streamhsa
2016-02-02 14:50:55 +05:30
parent e62a9e1bb7
commit e5a491f3c8
8 changed files with 54 additions and 66 deletions
+2 -2
View File
@@ -190,7 +190,7 @@ int computeGold(int *gpuData, const int len)
return true;
}
__global__ void HIP_FUNCTION(testKernel,int *g_odata)
__global__ void testKernel(hipLaunchParm lp,int *g_odata)
{
// access thread id
const unsigned int tid = hipBlockDim_x * hipBlockIdx_x + hipThreadIdx_x;
@@ -236,7 +236,7 @@ __global__ void HIP_FUNCTION(testKernel,int *g_odata)
// Atomic XOR
atomicXor(&g_odata[10], tid);
}
HIP_FUNCTION_END
int main(int argc, char **argv)
{